Minimal asynchronous, read-only storage used by Eagle inspection and loads.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exists(
EaglePath path) → Future< bool> -
list(
EaglePath directory) → Future< List< EagleSourceEntry> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readBytes(
EaglePath path) → Future< List< int> > -
readText(
EaglePath path) → Future< String> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited