EagleLibraryItem class final

An item metadata record paired with its stable library-relative locations.

Constructors

EagleLibraryItem({required EagleItem metadata, required EaglePath directoryPath, required EaglePath payloadPath})
const

Properties

directoryPath EaglePath
final
extension String
no setter
folders List<String>
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
isDeleted bool
no setter
metadata EagleItem
final
name String
no setter
payloadPath EaglePath
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited