loadEagleLibrary function
Loads either one complete immutable snapshot or bounded diagnostics.
Implementation
Future<EagleResult<EagleLibrary>> loadEagleLibrary(
EagleDocumentSource source,
) async => EagleLibraryLoader(source).load();
Loads either one complete immutable snapshot or bounded diagnostics.
Future<EagleResult<EagleLibrary>> loadEagleLibrary(
EagleDocumentSource source,
) async => EagleLibraryLoader(source).load();