EagleLibraryChanges class final

A settled differential between two valid native-library snapshots.

Constructors

EagleLibraryChanges({Iterable<String> addedItemIds = const <String>[], Iterable<String> changedItemIds = const <String>[], Iterable<String> removedItemIds = const <String>[], Iterable<String> payloadChangedItemIds = const <String>[], Iterable<EaglePath> changedDocuments = const <EaglePath>[], bool fullReconciliation = false})

Properties

addedItemIds Set<String>
final
changedDocuments Set<EaglePath>
final
changedItemIds Set<String>
final
fullReconciliation bool
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
payloadChangedItemIds Set<String>
final
removedItemIds Set<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited