EagleLibraryWatchUpdate class final
A successful snapshot update or a failed refresh retaining the last value.
Constructors
-
EagleLibraryWatchUpdate({required EagleLibrary snapshot, required EagleLibraryChanges changes, required Iterable<
EagleDiagnostic> diagnostics, required bool applied})
Properties
- applied → bool
-
final
- changes → EagleLibraryChanges
-
final
-
diagnostics
→ List<
EagleDiagnostic> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshot → EagleLibrary
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited