EagleResult<T> class
sealed
The result of an operation that can fail for an expected Eagle condition.
- Implementers
Constructors
-
EagleResult.failure(Iterable<
EagleDiagnostic> diagnostics) -
factory
- EagleResult.success(T value)
-
constfactory
Properties
-
diagnostics
→ List<
EagleDiagnostic> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited